#! perl

use strict;
use warnings;
use utf8;
use Carp;

package Text::Layout::Pango;

sub new {
    my ( $pkg, @data ) = @_;
    croak("Text::Layout::Pango: Not yet implemented");
}

1;
